<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="94"/>
        <location filename="../mainwindow.cpp" line="203"/>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>MX USB Unmounter</source>
        <translation>MX USB アンマウンタ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="52"/>
        <source>Double-Click to Unmount</source>
        <translation>ダブルクリックでアンマウントします</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Volume</source>
        <translation>ボリューム名</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>No Removable Device</source>
        <translation>リムーバブルデバイスなし</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="98"/>
        <source>Other partitions still mounted on device</source>
        <translation>他のパーティションがまだデバイスマウントしています</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>Unmounting %1</source>
        <translation>%1 をアンマウント</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>%1 is Safe to Remove</source>
        <translation>%1 は安全に取り外せます</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Unable to unmount, device in use</source>
        <translation>使用中なので取り外せません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>About</source>
        <translation>情報</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="160"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>List Devices</source>
        <translation>デバイス一覧</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="162"/>
        <source>Quit</source>
        <translation>中止</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <location filename="../mainwindow.cpp" line="246"/>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>Always show icon</source>
        <translation>常にアイコンを表示する</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <location filename="../mainwindow.cpp" line="249"/>
        <source>Hide icon when not in use</source>
        <translation>使用していない時はアイコンを隠す</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="230"/>
        <source>Autostart has been disabled.</source>
        <translation>自動起動が無効になっています。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="230"/>
        <source>Failed to disable autostart.</source>
        <translation>自動起動の無効化に失敗しました。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="231"/>
        <source>Autostart Disabled</source>
        <translation>自動起動が無効中</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>Enable Autostart</source>
        <translation>自動起動を有効にする</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <source>Autostart has been enabled.</source>
        <translation>自動起動が有効になりました。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <source>Failed to enable autostart.</source>
        <translation>自動起動の有効化に失敗しました。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>Autostart Enabled</source>
        <translation>自動起動が有効中</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="237"/>
        <source>Disable Autostart</source>
        <translation>自動起動を無効にする</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>Unmount</source>
        <translation>アンマウント</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>%1 Help</source>
        <translation>%1 ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="342"/>
        <source>About MX USB Unmounter</source>
        <translation>MX USB アンマウンタについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Quickly Unmount Removable Media</source>
        <translation>リムーバブルメディアを素早くアンマウントします</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Application icon will stay visible all the time.</source>
        <translation>アプリケーションのアイコンは常に表示された状態になります。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>Application icon is now hidden and will reappear when a new device is connected.</source>
        <translation>アプリケーションのアイコンを表示しませんが、新しいデバイスを接続すると再び表示します。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>Application icon will be hidden when there are no devices plugged in.</source>
        <translation>デバイスを一切接続していない場合、アプリケーションのアイコンは表示しません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>Icon Visibility</source>
        <translation>アイコンの表示／非表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Version</source>
        <translation>バージョン</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
</context>
</TS>
